FABuloso
========

**FABuloso** is a python tool to easily organize and deploy an `OpenStack <http://www.openstack.org>`_ architecture using `Fabric <http://docs.fabfile.org/>`_. *FABuloso* manages configuration with **components** within **catalogs**. For a more deeper insight about what *FABuloso* does and how it does, take a look at the documentation `introduction <http://fabuloso.stackops.org/introduction.html>`_.


Documentation
-------------

The *FABuloso* docs are hosted `here <http://fabuloso.stackops.org>`_.


Installation
------------

From the source code you can just run::

    $ python setup.py install


Tests
-----

Although we have not tests yet, you can execute the ``run_tests.sh`` script in order to check the code with *flake8*::

    $ ./run_tests.sh


License
-------

*FABuloso* is released under the *Apache 2.0* license.
